@@ -1,3 +1,13 @@
+__author__ = 'Haryo Bagas Assyafah'
+__copyright__ = 'Bear Au Jus - ジュースとくま @2021'
+__credits__ = ['Haryo Bagas Assyafah']
+__license__ = "MIT"
+__version__ = "2.0"
+__maintainer__ = "Haryo Bagas Assyafah"
+__email__ = "haryobagasasyafah6@gmail.com"
+__status__ = "Production"
+
+
 class Flavor:
 
     @staticmethod
